@@ -727,15 +727,6 @@ class Turtle:
 
     silence = sleep
 
-    # Demo figures
-
-    def star(self, n, side):
-        for _ in range(n):
-            self.forward(side)
-            self.right(360 / n)
-            self.forward(side)
-            self.left(720 / n)
-
 
 class Tortuga(Turtle):
 
